@@ -12,15 +12,13 @@
 #include "utils/sampling.h"
 #include "vector.h"
 
-#if PG_VERSION_NUM < 120000
-#error "Requires PostgreSQL 12+"
-#endif
-
 #define HNSW_MAX_DIM 2000
+#define HNSW_MAX_NNZ 1000
 
 /* Support functions */
 #define HNSW_DISTANCE_PROC 1
 #define HNSW_NORM_PROC 2
+#define HNSW_TYPE_INFO_PROC 3
 
 #define HNSW_VERSION	1
 #define HNSW_MAGIC_NUMBER 0xA953A953
@@ -80,7 +78,7 @@
 
 #if PG_VERSION_NUM < 130000
 #define list_delete_last(list) list_truncate(list, list_length(list) - 1)
-#define list_sort(list, cmp) list_qsort(list, cmp)
+#define list_sort(list, cmp) ((list) = list_qsort(list, cmp))
 #endif
 
 #define HnswIsElementTuple(tup) ((tup)->type == HNSW_ELEMENT_TUPLE_TYPE)
@@ -129,7 +127,7 @@ HnswPtrDeclare(HnswNeighborArray, HnswNeighborArrayRelptr, HnswNeighborArrayPtr)
 HnswPtrDeclare(HnswNeighborArrayPtr, HnswNeighborsRelptr, HnswNeighborsPtr);
 HnswPtrDeclare(char, DatumRelptr, DatumPtr);
 
-typedef struct HnswElementData
+struct HnswElementData
 {
 	HnswElementPtr next;
 	ItemPointerData heaptids[HNSW_HEAPTIDS];
@@ -144,7 +142,7 @@ typedef struct HnswElementData
 	BlockNumber neighborPage;
 	DatumPtr	value;
 	LWLock		lock;
-}			HnswElementData;
+};
 
 typedef HnswElementData * HnswElement;
 
@@ -155,12 +153,12 @@ typedef struct HnswCandidate
 	bool		closer;
 }			HnswCandidate;
 
-typedef struct HnswNeighborArray
+struct HnswNeighborArray
 {
 	int			length;
 	bool		closerSet;
 	HnswCandidate items[FLEXIBLE_ARRAY_MEMBER];
-}			HnswNeighborArray;
+};
 
 typedef struct HnswPairingHeapNode
 {
@@ -185,6 +183,7 @@ typedef struct HnswGraph
 
 	/* Entry state */
 	LWLock		entryLock;
+	LWLock		entryWaitLock;
 	HnswElementPtr entryPoint;
 
 	/* Allocations state */
@@ -234,6 +233,13 @@ typedef struct HnswAllocator
 	void	   *state;
 }			HnswAllocator;
 
+typedef struct HnswTypeInfo
+{
+	int			maxDimensions;
+	Datum		(*normalize) (PG_FUNCTION_ARGS);
+	void		(*checkValue) (Pointer v);
+}			HnswTypeInfo;
+
 typedef struct HnswBuildState
 {
 	/* Info */
@@ -241,6 +247,7 @@ typedef struct HnswBuildState
 	Relation	index;
 	IndexInfo  *indexInfo;
 	ForkNumber	forkNum;
+	const		HnswTypeInfo *typeInfo;
 
 	/* Settings */
 	int			dimensions;
@@ -261,7 +268,6 @@ typedef struct HnswBuildState
 	HnswGraph  *graph;
 	double		ml;
 	int			maxLevel;
-	Vector	   *normvec;
 
 	/* Memory */
 	MemoryContext graphCtx;
@@ -324,6 +330,7 @@ typedef HnswNeighborTupleData * HnswNeighborTuple;
 
 typedef struct HnswScanOpaqueData
 {
+	const		HnswTypeInfo *typeInfo;
 	bool		first;
 	List	   *w;
 	MemoryContext tmpCtx;
@@ -366,7 +373,8 @@ typedef struct HnswVacuumState
 int			HnswGetM(Relation index);
 int			HnswGetEfConstruction(Relation index);
 FmgrInfo   *HnswOptionalProcInfo(Relation index, uint16 procnum);
-bool		HnswNormValue(FmgrInfo *procinfo, Oid collation, Datum *value, Vector * result);
+Datum		HnswNormValue(const HnswTypeInfo * typeInfo, Oid collation, Datum value);
+bool		HnswCheckNorm(FmgrInfo *procinfo, Oid collation, Datum value);
 Buffer		HnswNewBuffer(Relation index, ForkNumber forkNum);
 void		HnswInitPage(Buffer buf, Page page);
 void		HnswInit(void);
@@ -385,10 +393,12 @@ void		HnswInitNeighbors(char *base, HnswElement element, int m, HnswAllocator *
 bool		HnswInsertTupleOnDisk(Relation index, Datum value, Datum *values, bool *isnull, ItemPointer heap_tid, bool building);
 void		HnswUpdateNeighborsOnDisk(Relation index, FmgrInfo *procinfo, Oid collation, HnswElement e, int m, bool checkExisting, bool building);
 void		HnswLoadElementFromTuple(HnswElement element, HnswElementTuple etup, bool loadHeaptids, bool loadVec);
-void		HnswLoadElement(HnswElement element, float *distance, Datum *q, Relation index, FmgrInfo *procinfo, Oid collation, bool loadVec);
+void		HnswLoadElement(HnswElement element, float *distance, Datum *q, Relation index, FmgrInfo *procinfo, Oid collation, bool loadVec, float *maxDistance);
 void		HnswSetElementTuple(char *base, HnswElementTuple etup, HnswElement element);
 void		HnswUpdateConnection(char *base, HnswElement element, HnswCandidate * hc, int lm, int lc, int *updateIdx, Relation index, FmgrInfo *procinfo, Oid collation);
 void		HnswLoadNeighbors(HnswElement element, Relation index, int m);
+void		HnswInitLockTranche(void);
+const		HnswTypeInfo *HnswGetTypeInfo(Relation index);
 PGDLLEXPORT void HnswParallelBuildMain(dsm_segment *seg, shm_toc *toc);
 
 /* Index access methods */
